@@ -18,12 +18,13 @@
 \******************************************************************************/
 #include <ctype.h>				/* char types                 */
 #include <errno.h>				/* errors                     */
+#include <limits.h>
 #include <stdio.h>				/* general includes           */
 #include <stdlib.h>				/* standard library           */
-#include <unistd.h>				/* unix std routines          */
 #include <signal.h>				/* unix signals               */
 #include <string.h>				/* string processing          */
 #include <strings.h>				/* string processing          */
+#include <unistd.h>				/* unix std routines          */
 #include <sys/types.h>				/* types                      */
 #include "hgetopt.h"
 
@@ -98,10 +99,17 @@ extern char EBCDIC[256];
 /* constants */
 #define KEY_PGDN        338
 #define KEY_PGUP        339
-#define HVERSION	"1.54"			/* the version of the source  */
+#define HVERSION	"1.55"			/* the version of the source  */
 #define MIN_COLS        70                      /* screen has to be 70< cols  */
 #define MIN_LINES       7     /* 8 - 1 */       /* the slk crap minuses 1 line*/
-#define KEY_TAB 	9			/* value for the tab key      */
+#define KEY_TAB 		9			/* value for the tab key      */
+#define FN_LEN			80
+
+#define AlphabetSize (UCHAR_MAX +1)		/* for portability            */
+
+#ifndef max
+#define max(a,b) ((a) >(b) ? (a) : (b))
+#endif
 
 FILE *fpIN, *fpOUT;				/* global file ptrs           */
 
