@@ -490,7 +490,7 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 		if (val != -1)				/* if val checks out  */
 							/* search for it      */
 		    val = hexSearch(fpIN, ch, cursorLoc(currentLine, col,
-			  editHex, BASE)+1, (editHex) ? ((count+1)/2) : count);
+			  editHex, BASE), (editHex) ? ((count+1)/2) : count);
 
 		if (val == -1) 				/* if nothing came up */
 		{
