@@ -68,12 +68,12 @@ int main(int argc, char *argv[])			/* main program       */
     int  row, col, x, retval = 1, val;			/* counters, etc.     */
     long int len;					/* len need to be long*/
 
-    windows = (WINS *) malloc(sizeof(WINS));		/* malloc windows     */
-    head = llalloc();					/* malloc list space  */
-    fpINfilename = (char *) malloc(81);			/* allocate in and    */
-    fpOUTfilename = (char *) malloc(81);		/* out file name ptrs */
-    printHex = TRUE;					/* address format     */
-    USE_EBCDIC = FALSE;					/*use ascii by default*/
+    windows = (WINS *) malloc(sizeof(WINS));	/* malloc windows     */
+    head = llalloc();							/* malloc list space  */
+    fpINfilename = (char *) malloc(FN_LEN+1);	/* allocate in and    */
+    fpOUTfilename = (char *) malloc(FN_LEN+1);	/* out file name ptrs */
+    printHex = TRUE;							/* address format     */
+    USE_EBCDIC = FALSE;							/*use ascii by default*/
 
 							/* get cmd line args  */
     len = parseArgs(argc, argv, fpINfilename, fpOUTfilename);
@@ -177,10 +177,10 @@ long parseArgs(int argc, char *argv[], char *fpINfilename, char *fpOUTfilename)
             case 'a':	printHex = FALSE;		/* decimal addresses  */
                         break;
 							/* infile             */
-	    case 'i':	strncpy(fpINfilename, optarg, 80);
+	    case 'i':	strncpy(fpINfilename, optarg, FN_LEN);
 			break;
 							/* outfile            */
-	    case 'o':   strncpy(fpOUTfilename, optarg, 80);
+	    case 'o':   strncpy(fpOUTfilename, optarg, FN_LEN);
 			break;
 
             case 'r':   resize = atoi(optarg);		/* don't resize screen*/
@@ -201,7 +201,7 @@ long parseArgs(int argc, char *argv[], char *fpINfilename, char *fpOUTfilename)
     argv += optind;
 
     if (argv[0])
-        strncpy(fpINfilename, argv[0], 80);
+        strncpy(fpINfilename, argv[0], FN_LEN);
 
     if (strcmp(fpINfilename, ""))
         if ((fpIN = fopen(fpINfilename, "r")) == NULL)
