@@ -88,14 +88,14 @@ hexList *insertItem(hexList *head, int loc, int val)
 \********************************************************/
 int searchList(hexList *head, int loc)
 {   
-    hexList *tmpHead  = llalloc();			/* allocate temp space*/
+    hexList *tmpHead;					/* allocate temp space*/
     tmpHead = head;					/* temp points to head*/
     while (tmpHead != NULL)				/* while not null     */
     {
         if (tmpHead->loc == loc)			/*if loc == return val*/
-            return tmpHead->val;
-	else
-	    tmpHead = tmpHead->next;			/* move to next item  */
+			return tmpHead->val;
+		else
+			tmpHead = tmpHead->next;	/* move to next item  */
     }
     return -1;
 }
@@ -107,42 +107,48 @@ int searchList(hexList *head, int loc)
 int writeChanges(WINS *win, FILE *fpIN, FILE *fpOUT,
 		 char *fpINfilename, char *fpOUTfilename)
 {   
-    unsigned int buff;					/* declare llist vars */
-    hexList *tmpHead;
-    tmpHead = llalloc();
-    tmpHead = head;
+    unsigned int buff,prev_loc;					/* declare llist vars */
+    hexList *tmpHead = head;
 
     if ((fpOUT = fopen(fpOUTfilename, "w+")) && fpIN)
-    {							/* open the write file*/
-        rewind(fpIN);					/* set file loc to 0  */
-	rewind(fpOUT);					
-	while ((buff = fgetc(fpIN)) != EOF)		/*write to file buffer*/
-	    fputc(buff, fpOUT);
+    {										/* open the write file*/
+        rewind(fpIN);						/* set file loc to 0  */
+		rewind(fpOUT);					
+		while ((buff = fgetc(fpIN)) != EOF)	/*write to file buffer*/
+			fputc(buff, fpOUT);
     }
     else if (!fpOUT && fpIN)				/* if no output file  */
     {
-	if (!(fpOUT = freopen(fpINfilename, "r+", fpIN)) || *fpOUTfilename)
-	{
+		if (!(fpOUT = freopen(fpINfilename, "r+", fpIN)) || *fpOUTfilename)
+		{
             popupWin("Cannot write to file: bad permissions", -1);
 
-	    return 1;
-	}
+			return 1;
+		}
     }
     else
     {
         popupWin("No data written.", -1);
 
-	return 1;
+		return 1;
     }
 
     rewind(fpIN);
     rewind(fpOUT);
+    prev_loc = -1;
     while (tmpHead != NULL)				/* write to file      */
     {
-	fseek(fpOUT, tmpHead->loc, SEEK_SET);
-	fputc(tmpHead->val, fpOUT);
-	tmpHead = tmpHead->next;
+	/* only print the latest change  from the linked list*/
+	if (prev_loc != tmpHead->loc) { 
+		fseek(fpOUT, tmpHead->loc, SEEK_SET);
+		fputc(tmpHead->val, fpOUT);
+	}
+	        prev_loc = tmpHead->loc;
+		tmpHead = tmpHead->next;
+
     }
+	
+    fflush(fpOUT);					/* flush buffto disk  */
     fpIN = fpOUT;
     rewind(fpIN);					/* reset file pointer */
     rewind(fpOUT);					/* to the beginning   */
@@ -159,10 +165,10 @@ int writeChanges(WINS *win, FILE *fpIN, FILE *fpOUT,
 \********************************************************/
 hexList *freeList(hexList *head)
 {
-    if (head) 						/* while head != NULL */
+    if (head != NULL) 						/* while head != NULL */
     {
         freeList(head->next);				/* check next item    */
-        free(head);					/* free the memory    */
+        free(head);							/* free the memory    */
     }
-    return NULL;					/* return NULL to head*/
+    return NULL;							/* return NULL to head*/
 } 
